@@ -89,11 +89,11 @@ def poetry_with_invalid_lockfile(
     return _project_factory("invalid_lock", project_factory, fixture_dir)
 
 
-def test_lock_check_outdated(
+def test_lock_check_outdated_legacy(
     command_tester_factory: CommandTesterFactory,
     poetry_with_outdated_lockfile: Poetry,
     http: type[httpretty.httpretty],
-):
+) -> None:
     http.disable()
 
     locker = Locker(
@@ -105,6 +105,7 @@ def test_lock_check_outdated(
     tester = command_tester_factory("lock", poetry=poetry_with_outdated_lockfile)
     status_code = tester.execute("--check")
     expected = (
+        "poetry lock --check is deprecated, use `poetry check --lock` instead.\n"
         "Error: poetry.lock is not consistent with pyproject.toml. "
         "Run `poetry lock [--no-update]` to fix it.\n"
     )
@@ -115,11 +116,11 @@ def test_lock_check_outdated(
     assert status_code == 1
 
 
-def test_lock_check_up_to_date(
+def test_lock_check_up_to_date_legacy(
     command_tester_factory: CommandTesterFactory,
     poetry_with_up_to_date_lockfile: Poetry,
     http: type[httpretty.httpretty],
-):
+) -> None:
     http.disable()
 
     locker = Locker(
@@ -133,6 +134,11 @@ def test_lock_check_up_to_date(
     expected = "poetry.lock is consistent with pyproject.toml.\n"
     assert tester.io.fetch_output() == expected
 
+    expected_error = (
+        "poetry lock --check is deprecated, use `poetry check --lock` instead.\n"
+    )
+    assert tester.io.fetch_error() == expected_error
+
     # exit with an error
     assert status_code == 0
 
@@ -141,7 +147,7 @@ def test_lock_no_update(
     command_tester_factory: CommandTesterFactory,
     poetry_with_old_lockfile: Poetry,
     repo: TestRepository,
-):
+) -> None:
     repo.add_package(get_package("sampleproject", "1.3.1"))
     repo.add_package(get_package("sampleproject", "2.0.0"))
 
@@ -178,7 +184,7 @@ def test_lock_no_update_path_dependencies(
     command_tester_factory: CommandTesterFactory,
     poetry_with_nested_path_deps_old_lockfile: Poetry,
     repo: TestRepository,
-):
+) -> None:
     """
     The lock file contains a variant of the directory dependency "quix" that does
     not depend on "sampleproject". Although the version of "quix" has not been changed,
@@ -204,6 +210,63 @@ def test_lock_no_update_path_dependencies(
     assert {p.name for p in packages} == {"quix", "sampleproject"}
 
 
+@pytest.mark.parametrize("update", [True, False])
+@pytest.mark.parametrize(
+    "project", ["missing_directory_dependency", "missing_file_dependency"]
+)
+def test_lock_path_dependency_does_not_exist(
+    command_tester_factory: CommandTesterFactory,
+    project_factory: ProjectFactory,
+    fixture_dir: FixtureDirGetter,
+    project: str,
+    update: bool,
+) -> None:
+    poetry = _project_factory(project, project_factory, fixture_dir)
+    locker = Locker(
+        lock=poetry.pyproject.file.path.parent / "poetry.lock",
+        local_config=poetry.locker._local_config,
+    )
+    poetry.set_locker(locker)
+    options = "" if update else "--no-update"
+
+    tester = command_tester_factory("lock", poetry=poetry)
+    if update or "directory" in project:
+        # directory dependencies are always updated
+        with pytest.raises(ValueError, match="does not exist"):
+            tester.execute(options)
+    else:
+        tester.execute(options)
+
+
+@pytest.mark.parametrize("update", [True, False])
+@pytest.mark.parametrize(
+    "project", ["deleted_directory_dependency", "deleted_file_dependency"]
+)
+def test_lock_path_dependency_deleted_from_pyproject(
+    command_tester_factory: CommandTesterFactory,
+    project_factory: ProjectFactory,
+    fixture_dir: FixtureDirGetter,
+    project: str,
+    update: bool,
+) -> None:
+    poetry = _project_factory(project, project_factory, fixture_dir)
+    locker = Locker(
+        lock=poetry.pyproject.file.path.parent / "poetry.lock",
+        local_config=poetry.locker._local_config,
+    )
+    poetry.set_locker(locker)
+
+    tester = command_tester_factory("lock", poetry=poetry)
+    if update:
+        tester.execute("")
+    else:
+        tester.execute("--no-update")
+
+    packages = locker.locked_repository().packages
+
+    assert {p.name for p in packages} == set()
+
+
 @pytest.mark.parametrize("is_no_update", [False, True])
 def test_lock_with_incompatible_lockfile(
     command_tester_factory: CommandTesterFactory,
