@@ -13,6 +13,7 @@ import requests
 from packaging.utils import canonicalize_name
 from poetry.core.constraints.version import Version
 from poetry.core.packages.dependency import Dependency
+from poetry.core.packages.utils.link import Link
 
 from poetry.factory import Factory
 from poetry.repositories.exceptions import PackageNotFound
@@ -21,11 +22,6 @@ from poetry.repositories.legacy_repository import LegacyRepository
 from poetry.repositories.link_sources.html import SimpleRepositoryPage
 
 
-try:
-    import urllib.parse as urlparse
-except ImportError:
-    import urlparse
-
 if TYPE_CHECKING:
     import httpretty
 
@@ -55,7 +51,7 @@ class MockRepository(LegacyRepository):
             return SimpleRepositoryPage(self._url + f"/{name}/", f.read())
 
     def _download(self, url: str, dest: Path) -> None:
-        filename = urlparse.urlparse(url).path.rsplit("/")[-1]
+        filename = Link(url).filename
         filepath = self.FIXTURES.parent / "pypi.org" / "dists" / filename
 
         shutil.copyfile(str(filepath), dest)
@@ -119,6 +115,30 @@ def test_page_invalid_version_link() -> None:
     assert packages[0].version.to_string() == "0.1.0"
 
 
+def test_page_filters_out_invalid_package_names() -> None:
+    class SpecialMockRepository(MockRepository):
+        def _get_page(self, name: NormalizedName) -> SimpleRepositoryPage:
+            return super()._get_page(canonicalize_name(f"{name}-with-extra-packages"))
+
+    repo = SpecialMockRepository()
+    packages = repo.find_packages(Factory.create_dependency("pytest", "*"))
+    assert len(packages) == 1
+    assert packages[0].name == "pytest"
+    assert packages[0].version == Version.parse("3.5.0")
+
+    package = repo.package("pytest", Version.parse("3.5.0"))
+    assert package.files == [
+        {
+            "file": "pytest-3.5.0-py2.py3-none-any.whl",
+            "hash": "sha256:6266f87ab64692112e5477eba395cfedda53b1933ccd29478e671e73b420c19c",  # noqa: E501
+        },
+        {
+            "file": "pytest-3.5.0.tar.gz",
+            "hash": "sha256:fae491d1874f199537fd5872b5e1f0e74a009b979df9d53d1553fd03da1703e1",  # noqa: E501
+        },
+    ]
+
+
 def test_sdist_format_support() -> None:
     repo = MockRepository()
     page = repo.get_page("relative")
@@ -176,7 +196,7 @@ def test_get_package_information_skips_dependencies_with_invalid_constraints() -
         Dependency("python-jsonrpc-server", "*"),
     ]
 
-    all_extra = package.extras["all"]
+    all_extra = package.extras[canonicalize_name("all")]
 
     # rope>-0.10.5 should be discarded
     assert sorted(all_extra, key=lambda r: r.name) == [
@@ -211,7 +231,7 @@ def test_find_packages_no_prereleases() -> None:
 
 
 @pytest.mark.parametrize(
-    ["constraint", "count"], [("*", 1), (">=1", 0), (">=19.0.0a0", 1)]
+    ["constraint", "count"], [("*", 1), (">=1", 1), ("<=18", 0), (">=19.0.0a0", 1)]
 )
 def test_find_packages_only_prereleases(constraint: str, count: int) -> None:
     repo = MockRepository()
@@ -226,13 +246,6 @@ def test_find_packages_only_prereleases(constraint: str, count: int) -> None:
             assert package.source_url == repo.url
 
 
-def test_find_packages_only_prereleases_empty_when_not_any() -> None:
-    repo = MockRepository()
-    packages = repo.find_packages(Factory.create_dependency("black", ">=1"))
-
-    assert len(packages) == 0
-
-
 @pytest.mark.parametrize(
     ["constraint", "expected"],
     [
@@ -437,7 +450,7 @@ def test_package_yanked(
     assert package.yanked_reason == yanked_reason
 
 
-def test_package_partial_yank():
+def test_package_partial_yank() -> None:
     class SpecialMockRepository(MockRepository):
         def _get_page(self, name: NormalizedName) -> SimpleRepositoryPage:
             return super()._get_page(canonicalize_name(f"{name}-partial-yank"))
@@ -473,9 +486,17 @@ def test_find_links_for_package_yanked(
         assert link.yanked_reason == yanked_reason
 
 
+def test_cached_or_downloaded_file_supports_trailing_slash() -> None:
+    repo = MockRepository()
+    with repo._cached_or_downloaded_file(
+        Link("https://foo.bar/pytest-3.5.0-py2.py3-none-any.whl/")
+    ) as filepath:
+        assert filepath.name == "pytest-3.5.0-py2.py3-none-any.whl"
+
+
 class MockHttpRepository(LegacyRepository):
     def __init__(
-        self, endpoint_responses: dict, http: type[httpretty.httpretty]
+        self, endpoint_responses: dict[str, int], http: type[httpretty.httpretty]
     ) -> None:
         base_url = "http://legacy.foo.bar"
         super().__init__("legacy", url=base_url, disable_cache=True)
@@ -488,7 +509,7 @@ class MockHttpRepository(LegacyRepository):
 def test_get_200_returns_page(http: type[httpretty.httpretty]) -> None:
     repo = MockHttpRepository({"/foo/": 200}, http)
 
-    assert repo.get_page("foo")
+    _ = repo.get_page("foo")
 
 
 @pytest.mark.parametrize("status_code", [401, 403, 404])
